@@ -11,6 +11,7 @@ impl_handle! { HPALETTE;
 	/// [palette](https://learn.microsoft.com/en-us/windows/win32/winprog/windows-data-types#hpalette).
 }
 
+impl GdiObject for HPALETTE {}
 impl gdi_Hpalette for HPALETTE {}
 
 /// This trait is enabled with the `gdi` feature, and provides methods for
@@ -25,10 +26,13 @@ pub trait gdi_Hpalette: Handle {
 	/// [`CreatePalette`](https://learn.microsoft.com/en-us/windows/win32/api/wingdi/nf-wingdi-createpalette)
 	/// function.
 	#[must_use]
-	fn CreatePalette(pal: &LOGPALETTE) -> SysResult<DeleteObjectPaletteGuard> {
+	fn CreatePalette(
+		pal: &LOGPALETTE,
+	) -> SysResult<DeleteObjectGuard<HPALETTE>>
+	{
 		unsafe {
 			ptr_to_sysresult_handle(ffi::CreatePalette(pal as *const _ as _))
-				.map(|h| DeleteObjectPaletteGuard::new(h))
+				.map(|h| DeleteObjectGuard::new(h))
 		}
 	}
 }
